
local _, TzDR = ...

-----------------------------------
-- TzRaresPanel_CreateBackground --
-----------------------------------
local function TzRaresPanel_CreateBackground( _panel, _name, _parent, _text )
	local head = TzDR.panel:CreateFontString( _panel:GetName() .. "_" .. _name .. "_Head", "ARTWORK", "GameFontNormal" )
	head:ClearAllPoints()
	head:SetPoint( "TOPLEFT", _parent:GetName(), "BOTTOMLEFT", 16, -8 )
	head:SetText( _text )

	local background = CreateFrame( "Frame", _panel:GetName() .. "_" .. _name .. "_Background", _panel )
	background:SetSize( 308, 62 )
	background:SetBackdrop( {	bgFile = "Interface/TutorialFrame/TutorialFrameBackground",
								edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
								tile = true,
								tileSize = 8,
								edgeSize = 14,
								insets = { left = 3, right = 3, top = 3, bottom = 3 } } )
	background:ClearAllPoints()
	background:SetPoint( "TOPLEFT", head:GetName(), "BOTTOMLEFT", -16, -2 )

	return background
end

------------------------------------
-- TzRaresPanel_CreateCheckButton --
------------------------------------
local function TzRaresPanel_CreateCheckButton( _panel, _name, _background, _text )
	local checkbutton = CreateFrame( "CheckButton", _panel:GetName() .. "_" .. _name .. "_CheckButton", _background, "OptionsCheckButtonTemplate" )
	checkbutton:ClearAllPoints()
	checkbutton:SetPoint( "TOPLEFT", _background:GetName(), "TOPLEFT", 18, -18 )

	checkbutton.text = _background:CreateFontString( _panel:GetName() .. "_" .. _name .. "_CheckButton_Text", "ARTWORK", "GameFontHighlight" )
	checkbutton.text:ClearAllPoints()
	checkbutton.text:SetPoint( "LEFT", checkbutton:GetName(), "RIGHT", 0, 1 )
	checkbutton.text:SetText( _text )

	return checkbutton
end

-------------------------------
-- TzRaresPanel_CreateSlider --
-------------------------------
local function TzRaresPanel_CreateSlider( _panel, _name, _background, _text, _low, _high )
	local slider = CreateFrame( "Slider", _panel:GetName() .. "_" .. _name .. "_Slider", _background, "OptionsSliderTemplate" )

	slider:ClearAllPoints()
	slider:SetPoint( "TOPLEFT", _background:GetName(), "TOPLEFT", 128, -24 )
	slider:SetMinMaxValues( 1, 64 )
	slider:SetValueStep( 1 )

	getglobal( slider:GetName() .. "Low" ):SetText( _low )
	getglobal( slider:GetName() .. "High" ):SetText( _high )
	getglobal( slider:GetName() .. "Text" ):SetText( _text )

	slider.value = _background:CreateFontString( _panel:GetName() .. "_" .. _name .. "_Slider_Value", "ARTWORK", "GameFontHighlight" )
	slider.value:ClearAllPoints()
	slider.value:SetPoint( "CENTER", slider:GetName(), "CENTER", 0, -12 )
	slider.value:SetText( "16" )

	slider:SetScript( "OnValueChanged",
	function( _self, _value )
-- ValueStep bug fix begin
		if not _self._onsetting then
			_self._onsetting = true
			_self:SetValue( _self:GetValue() )
			_value = _self:GetValue()
			_self._onsetting = false
		else
			return
		end
-- ValueStep bug fix end

		slider.value:SetText( _value )
	end )

	return slider
end

-------------------------
-- TzRaresPanel_OnLoad --
-------------------------
function TzRaresPanel_OnLoad( _self )
	TzDR.panel = _self
	TzDR.panel:RegisterEvent( "ADDON_LOADED" )

	TzDR.panel.name = "Tz: Rares"
	TzDR.panel.okay = function ( _self ) TzRaresPanel_OnOkay() end
	TzDR.panel.cancel = function ( _self ) TzRaresPanel_OnCancel() end
	InterfaceOptions_AddCategory( TzDR.panel )

	TzDR.panel.head = TzDR.panel:CreateFontString( TzDR.panel:GetName() .. "_Head", "ARTWORK", "GameFontNormalLarge" )
	TzDR.panel.head:ClearAllPoints()
	TzDR.panel.head:SetPoint( "TOPLEFT", TzDR.panel, "TOPLEFT", 16, -16 )
	TzDR.panel.head:SetText( TzDR.panel.name )

----------------------------------------------------------------
-- Draenor Rares

	TzDR.panel.draenorrares					= {}
	TzDR.panel.draenorrares.background		= TzRaresPanel_CreateBackground( TzDR.panel, "DraenorRares", TzDR.panel.head, "Draenor Rare Icons" )
	TzDR.panel.draenorrares.checkbutton		= TzRaresPanel_CreateCheckButton( TzDR.panel, "DraenorRares", TzDR.panel.draenorrares.background, "Show" )
	TzDR.panel.draenorrares.slider			= TzRaresPanel_CreateSlider( TzDR.panel, "DraenorRares", TzDR.panel.draenorrares.background, "Icon Scale", "1", "64" )

-- Draenor Rares

	TzDR.panel.pandariarares				= {}
	TzDR.panel.pandariarares.background		= TzRaresPanel_CreateBackground( TzDR.panel, "PandariaRares", TzDR.panel.draenorrares.background, "Pandaria Rare Icons" )
	TzDR.panel.pandariarares.checkbutton	= TzRaresPanel_CreateCheckButton( TzDR.panel, "PandariaRares", TzDR.panel.pandariarares.background, "Show" )
	TzDR.panel.pandariarares.slider			= TzRaresPanel_CreateSlider( TzDR.panel, "PandariaRares", TzDR.panel.pandariarares.background, "Icon Scale", "1", "64" )

end

--------------------------
-- TzRaresPanel_OnEvent --
--------------------------
function TzRaresPanel_OnEvent( _self, _event, _name )
	if( _event == "ADDON_LOADED" and _name == "TzRares" ) then

		if TzRaresOptions						== nil then	TzRaresOptions = {}							end
		if TzRaresOptions.draenorrares_show		== nil then	TzRaresOptions.draenorrares_show	= true	end
		if TzRaresOptions.draenorrares_scale	== nil then	TzRaresOptions.draenorrares_scale	= 24	end

		if TzRaresOptions						== nil then	TzRaresOptions = {}							end
		if TzRaresOptions.pandariarares_show	== nil then	TzRaresOptions.pandariarares_show	= true	end
		if TzRaresOptions.pandariarares_scale	== nil then	TzRaresOptions.pandariarares_scale	= 24	end

		TzRaresPanel_OnCancel()
	end
end

-------------------------
-- TzRaresPanel_OnOkay --
-------------------------
function TzRaresPanel_OnOkay( _self )
	TzRaresOptions.draenorrares_show	= TzDR.panel.draenorrares.checkbutton:GetChecked()
	TzRaresOptions.draenorrares_scale	= TzDR.panel.draenorrares.slider:GetValue()

	TzRaresOptions.pandariarares_show	= TzDR.panel.pandariarares.checkbutton:GetChecked()
	TzRaresOptions.pandariarares_scale	= TzDR.panel.pandariarares.slider:GetValue()
end

---------------------------
-- TzRaresPanel_OnCancel --
---------------------------
function TzRaresPanel_OnCancel( _self )
	TzDR.panel.draenorrares.checkbutton:SetChecked(		TzRaresOptions.draenorrares_show )
	TzDR.panel.draenorrares.slider:SetValue(			TzRaresOptions.draenorrares_scale )

	TzDR.panel.pandariarares.checkbutton:SetChecked(	TzRaresOptions.pandariarares_show )
	TzDR.panel.pandariarares.slider:SetValue(			TzRaresOptions.pandariarares_scale )
end
